diff --git a/MediaBrowser.Api/Playback/BaseStreamingService.cs b/MediaBrowser.Api/Playback/BaseStreamingService.cs
index 34c5e5f7c8..c4cdfc9edd 100644
--- a/MediaBrowser.Api/Playback/BaseStreamingService.cs
+++ b/MediaBrowser.Api/Playback/BaseStreamingService.cs
@@ -126,7 +126,7 @@ namespace MediaBrowser.Api.Playback
var data = GetCommandLineArguments("dummy\\dummy", state, false);
data += "-" + (state.Request.DeviceId ?? string.Empty);
- data += "-" + (state.Request.StreamId ?? string.Empty);
+ data += "-" + (state.Request.PlaySessionId ?? string.Empty);
data += "-" + (state.Request.ClientTime ?? string.Empty);
var dataHash = data.GetMD5().ToString("N");
@@ -1009,7 +1009,7 @@ namespace MediaBrowser.Api.Playback
}
var transcodingJob = ApiEntryPoint.Instance.OnTranscodeBeginning(outputPath,
- state.Request.StreamId,
+ state.Request.PlaySessionId,
transcodingId,
TranscodingJobType,
process,
@@ -1511,7 +1511,7 @@ namespace MediaBrowser.Api.Playback
}
else if (i == 21)
{
- request.StreamId = val;
+ request.PlaySessionId = val;
}
else if (i == 22)
{
diff --git a/MediaBrowser.Api/Playback/Dash/MpegDashService.cs b/MediaBrowser.Api/Playback/Dash/MpegDashService.cs
index 692e8d4e74..ba3f172579 100644
--- a/MediaBrowser.Api/Playback/Dash/MpegDashService.cs
+++ b/MediaBrowser.Api/Playback/Dash/MpegDashService.cs
@@ -160,7 +160,7 @@ namespace MediaBrowser.Api.Playback.Dash
// If the playlist doesn't already exist, startup ffmpeg
try
{
- ApiEntryPoint.Instance.KillTranscodingJobs(request.DeviceId, request.StreamId, p => false);
+ ApiEntryPoint.Instance.KillTranscodingJobs(request.DeviceId, request.PlaySessionId, p => false);
if (currentTranscodingIndex.HasValue)
{
diff --git a/MediaBrowser.Api/Playback/Hls/DynamicHlsService.cs b/MediaBrowser.Api/Playback/Hls/DynamicHlsService.cs
index 4f7c0444b2..4f043d3217 100644
--- a/MediaBrowser.Api/Playback/Hls/DynamicHlsService.cs
+++ b/MediaBrowser.Api/Playback/Hls/DynamicHlsService.cs
@@ -135,7 +135,7 @@ namespace MediaBrowser.Api.Playback.Hls
// If the playlist doesn't already exist, startup ffmpeg
try
{
- ApiEntryPoint.Instance.KillTranscodingJobs(request.DeviceId, request.StreamId, p => false);
+ ApiEntryPoint.Instance.KillTranscodingJobs(request.DeviceId, request.PlaySessionId, p => false);
if (currentTranscodingIndex.HasValue)
{
diff --git a/MediaBrowser.Api/Playback/Hls/HlsSegmentService.cs b/MediaBrowser.Api/Playback/Hls/HlsSegmentService.cs
index 1fe0661d9f..5d8c67abe9 100644
--- a/MediaBrowser.Api/Playback/Hls/HlsSegmentService.cs
+++ b/MediaBrowser.Api/Playback/Hls/HlsSegmentService.cs
@@ -54,8 +54,8 @@ namespace MediaBrowser.Api.Playback.Hls
[ApiMember(Name = "DeviceId", Description = "The device id of the client requesting. Used to stop encoding processes when needed.", IsRequired = true, DataType = "string", ParameterType = "query", Verb = "DELETE")]
public string DeviceId { get; set; }
- [ApiMember(Name = "StreamId", Description = "The stream id", IsRequired = true, DataType = "string", ParameterType = "query", Verb = "DELETE")]
- public string StreamId { get; set; }
+ [ApiMember(Name = "PlaySessionId", Description = "The play session id", IsRequired = true, DataType = "string", ParameterType = "query", Verb = "DELETE")]
+ public string PlaySessionId { get; set; }
}
///
@@ -95,7 +95,7 @@ namespace MediaBrowser.Api.Playback.Hls
public void Delete(StopEncodingProcess request)
{
- ApiEntryPoint.Instance.KillTranscodingJobs(request.DeviceId, request.StreamId, path => true);
+ ApiEntryPoint.Instance.KillTranscodingJobs(request.DeviceId, request.PlaySessionId, path => true);
}
///
diff --git a/MediaBrowser.Api/Playback/MediaInfoService.cs b/MediaBrowser.Api/Playback/MediaInfoService.cs
index 6f8c2cc505..c6678d1ed1 100644
--- a/MediaBrowser.Api/Playback/MediaInfoService.cs
+++ b/MediaBrowser.Api/Playback/MediaInfoService.cs
@@ -194,7 +194,7 @@ namespace MediaBrowser.Api.Playback
}
else
{
- result.StreamId = Guid.NewGuid().ToString("N");
+ result.PlaySessionId = Guid.NewGuid().ToString("N");
}
return result;
diff --git a/MediaBrowser.Api/Playback/StreamRequest.cs b/MediaBrowser.Api/Playback/StreamRequest.cs
index 7ed4fcd965..75242e604c 100644
--- a/MediaBrowser.Api/Playback/StreamRequest.cs
+++ b/MediaBrowser.Api/Playback/StreamRequest.cs
@@ -71,7 +71,7 @@ namespace MediaBrowser.Api.Playback
public string Params { get; set; }
public string ClientTime { get; set; }
- public string StreamId { get; set; }
+ public string PlaySessionId { get; set; }
public string LiveStreamId { get; set; }
}
diff --git a/MediaBrowser.Model/Dlna/StreamInfo.cs b/MediaBrowser.Model/Dlna/StreamInfo.cs
index dc24627960..12319a1227 100644
--- a/MediaBrowser.Model/Dlna/StreamInfo.cs
+++ b/MediaBrowser.Model/Dlna/StreamInfo.cs
@@ -206,8 +206,8 @@ namespace MediaBrowser.Model.Dlna
list.Add(new NameValuePair("Profile", item.VideoProfile ?? string.Empty));
list.Add(new NameValuePair("Cabac", item.Cabac.HasValue ? item.Cabac.Value.ToString() : string.Empty));
- string streamId = item.PlaybackInfo == null ? null : item.PlaybackInfo.StreamId;
- list.Add(new NameValuePair("StreamId", streamId ?? string.Empty));
+ string playSessionId = item.PlaybackInfo == null ? null : item.PlaybackInfo.PlaySessionId;
+ list.Add(new NameValuePair("PlaySessionId", playSessionId ?? string.Empty));
list.Add(new NameValuePair("api_key", accessToken ?? string.Empty));
string liveStreamId = item.MediaSource == null ? null : item.MediaSource.LiveStreamId;
diff --git a/Nuget/MediaBrowser.Common.Internal.nuspec b/Nuget/MediaBrowser.Common.Internal.nuspec
index ee3bdd2b6b..57a1db722d 100644
--- a/Nuget/MediaBrowser.Common.Internal.nuspec
+++ b/Nuget/MediaBrowser.Common.Internal.nuspec
@@ -2,7 +2,7 @@
MediaBrowser.Common.Internal
- 3.0.606
+ 3.0.607
MediaBrowser.Common.Internal
Luke
ebr,Luke,scottisafool
@@ -12,7 +12,7 @@
Contains common components shared by Emby Theater and Emby Server. Not intended for plugin developer consumption.
Copyright © Emby 2013
-
+
diff --git a/Nuget/MediaBrowser.Common.nuspec b/Nuget/MediaBrowser.Common.nuspec
index a8f3ea1f38..9ad9c18ca2 100644
--- a/Nuget/MediaBrowser.Common.nuspec
+++ b/Nuget/MediaBrowser.Common.nuspec
@@ -2,7 +2,7 @@
MediaBrowser.Common
- 3.0.606
+ 3.0.607
MediaBrowser.Common
Emby Team
ebr,Luke,scottisafool
diff --git a/Nuget/MediaBrowser.Model.Signed.nuspec b/Nuget/MediaBrowser.Model.Signed.nuspec
index 7bd4a090dd..261ddd37d1 100644
--- a/Nuget/MediaBrowser.Model.Signed.nuspec
+++ b/Nuget/MediaBrowser.Model.Signed.nuspec
@@ -2,7 +2,7 @@
MediaBrowser.Model.Signed
- 3.0.606
+ 3.0.607
MediaBrowser.Model - Signed Edition
Emby Team
ebr,Luke,scottisafool
diff --git a/Nuget/MediaBrowser.Server.Core.nuspec b/Nuget/MediaBrowser.Server.Core.nuspec
index 3f39ace9dd..49a38aaeb3 100644
--- a/Nuget/MediaBrowser.Server.Core.nuspec
+++ b/Nuget/MediaBrowser.Server.Core.nuspec
@@ -2,7 +2,7 @@
MediaBrowser.Server.Core
- 3.0.606
+ 3.0.607
Media Browser.Server.Core
Emby Team
ebr,Luke,scottisafool
@@ -12,7 +12,7 @@
Contains core components required to build plugins for Emby Server.
Copyright © Emby 2013
-
+
diff --git a/MediaBrowser.Api/ApiEntryPoint.cs b/MediaBrowser.Api/ApiEntryPoint.cs
index 9f4ad58937..444977e352 100644
--- a/MediaBrowser.Api/ApiEntryPoint.cs
+++ b/MediaBrowser.Api/ApiEntryPoint.cs
@@ -132,7 +132,7 @@ namespace MediaBrowser.Api
/// Called when [transcode beginning].
///
/// The path.
- /// The stream identifier.
+ /// The play session identifier.
/// The transcoding job identifier.
/// The type.
/// The process.
@@ -141,7 +141,7 @@ namespace MediaBrowser.Api
/// The cancellation token source.
/// TranscodingJob.
public TranscodingJob OnTranscodeBeginning(string path,
- string streamId,
+ string playSessionId,
string transcodingJobId,
TranscodingJobType type,
Process process,
@@ -160,7 +160,7 @@ namespace MediaBrowser.Api
DeviceId = deviceId,
CancellationTokenSource = cancellationTokenSource,
Id = transcodingJobId,
- StreamId = streamId
+ PlaySessionId = playSessionId
};
_activeTranscodingJobs.Add(job);
@@ -324,10 +324,10 @@ namespace MediaBrowser.Api
/// Kills the single transcoding job.
///
/// The device id.
- /// The stream identifier.
+ /// The play session identifier.
/// The delete files.
/// Task.
- internal void KillTranscodingJobs(string deviceId, string streamId, Func deleteFiles)
+ internal void KillTranscodingJobs(string deviceId, string playSessionId, Func deleteFiles)
{
if (string.IsNullOrEmpty(deviceId))
{
@@ -338,7 +338,7 @@ namespace MediaBrowser.Api
{
if (string.Equals(deviceId, j.DeviceId, StringComparison.OrdinalIgnoreCase))
{
- return string.IsNullOrWhiteSpace(streamId) || string.Equals(streamId, j.StreamId, StringComparison.OrdinalIgnoreCase);
+ return string.IsNullOrWhiteSpace(playSessionId) || string.Equals(playSessionId, j.PlaySessionId, StringComparison.OrdinalIgnoreCase);
}
return false;
@@ -539,10 +539,10 @@ namespace MediaBrowser.Api
public class TranscodingJob
{
///
/// Gets or sets the stream identifier.
///
- /// The stream identifier.
- public string StreamId { get; set; }
+ /// The play session identifier.
+ public string PlaySessionId { get; set; }
///
/// Gets or sets the path.
///
@@ -539,10 +539,10 @@ namespace MediaBrowser.Api
{
///
- /// Gets or sets the stream identifier.
+ /// Gets or sets the play session identifier.
///
diff --git a/MediaBrowser.Model/MediaInfo/PlaybackInfoResponse.cs b/MediaBrowser.Model/MediaInfo/PlaybackInfoResponse.cs
index ed0824e8a4..1f8936d018 100644
--- a/MediaBrowser.Model/MediaInfo/PlaybackInfoResponse.cs
+++ b/MediaBrowser.Model/MediaInfo/PlaybackInfoResponse.cs
@@ -13,10 +13,10 @@ namespace MediaBrowser.Model.MediaInfo
public List MediaSources { get; set; }
///
/// Gets or sets the stream identifier.
///
- /// The stream identifier.
- public string StreamId { get; set; }
+ /// The play session identifier.
+ public string PlaySessionId { get; set; }
///
/// Gets or sets the error code.
@@ -13,10 +13,10 @@ namespace MediaBrowser.Model.MediaInfo
public List MediaSources { get; set; }
///
- /// Gets or sets the stream identifier.
+ /// Gets or sets the play session identifier.
///